@@ -24,6 +24,7 @@ ensure_bitarray(PyObject *obj)
     t = PyObject_IsInstance(obj, bitarray_type_obj);
     if (t < 0)
         return -1;
+
     if (t == 0) {
         PyErr_Format(PyExc_TypeError, "bitarray expected, not '%s'",
                      Py_TYPE(obj)->tp_name);
@@ -32,32 +33,40 @@ ensure_bitarray(PyObject *obj)
     return 0;
 }
 
-/* return new bitarray of length `nbits` (with uninitialized buffer) and
-   endianness given by the PyObject 'endian' (which may be Py_None) */
+/* Return new bitarray of length 'nbits', endianness given by the PyObject
+   'endian' (which may be Py_None).
+   Unless -1, 'c' is placed into all characters of buffer. */
 static bitarrayobject *
-new_bitarray(Py_ssize_t nbits, PyObject *endian)
+new_bitarray(Py_ssize_t nbits, PyObject *endian, int c)
 {
     PyObject *args;             /* args for bitarray() */
     bitarrayobject *res;
 
-    if ((args = PyTuple_New(2)) == NULL)
+    if ((args = PyTuple_New(3)) == NULL)  /* arguments for bitarray() */
         return NULL;
 
     /* PyTuple_SET_ITEM "steals" a reference to item */
     PyTuple_SET_ITEM(args, 0, PyLong_FromSsize_t(nbits));
     Py_INCREF(endian);
     PyTuple_SET_ITEM(args, 1, endian);
+    Py_INCREF(Py_Ellipsis);
+    PyTuple_SET_ITEM(args, 2, Py_Ellipsis);
 
+    /* equivalent to: res = bitarray(nbits, endian, Ellipsis) */
     res = (bitarrayobject *) PyObject_CallObject(bitarray_type_obj, args);
     Py_DECREF(args);
     if (res == NULL)
         return NULL;
+
     assert(res->nbits == nbits && res->readonly == 0 && res->buffer == NULL);
+    assert(-1 <= c && c < 256);
+    if (c >= 0)
+        memset(res->ob_item, c, (size_t) Py_SIZE(res));
 
     return res;
 }
 
-/* Starting from word index `i`, count remaining population in bitarray
+/* Starting from word index 'i', count remaining population in bitarray
    buffer.  Equivalent to:  a[64 * i:].count()  */
 static Py_ssize_t
 count_from_word(bitarrayobject *a, Py_ssize_t i)
@@ -82,7 +91,7 @@ zeros(PyObject *module, PyObject *args, PyObject *kwds)
                                      &nbits, &endian))
         return NULL;
 
-    return (PyObject *) new_bitarray(nbits, endian);
+    return (PyObject *) new_bitarray(nbits, endian, 0);
 }
 
 PyDoc_STRVAR(zeros_doc,
@@ -97,19 +106,13 @@ ones(PyObject *module, PyObject *args, PyObject *kwds)
 {
     static char *kwlist[] = {"", "endian", NULL};
     PyObject *endian = Py_None;
-    bitarrayobject *a;
     Py_ssize_t nbits;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "n|O:ones", kwlist,
                                      &nbits, &endian))
         return NULL;
 
-    if ((a = new_bitarray(nbits, endian)) == NULL)
-        return NULL;
-
-    memset(a->ob_item, 0xff, (size_t) Py_SIZE(a));
-
-    return (PyObject *) a;
+    return (PyObject *) new_bitarray(nbits, endian, 0xff);
 }
 
 PyDoc_STRVAR(ones_doc,
@@ -450,9 +453,9 @@ deserialize(PyObject *module, PyObject *buffer)
         PyErr_Format(PyExc_ValueError, "invalid header byte: 0x%02x", head);
         goto error;
     }
-    /* create bitarray of desired length (buffer uninitialized) */
+    /* create bitarray of desired length */
     a = new_bitarray(8 * (view.len - 1) - ((Py_ssize_t) (head & 0x07)),
-                     Py_None);
+                     Py_None, -1);
     if (a == NULL)
         goto error;
     /* set bit-endianness and buffer */
@@ -502,10 +505,9 @@ ba2hex(PyObject *module, PyObject *obj)
         return NULL;
 
     a = (bitarrayobject *) obj;
-    if (a->nbits % 4) {
-        PyErr_SetString(PyExc_ValueError, "bitarray length not multiple of 4");
-        return NULL;
-    }
+    if (a->nbits % 4)
+        return PyErr_Format(PyExc_ValueError, "bitarray length %zd not "
+                            "multiple of 4", a->nbits);
 
     /* We want strsize to be even, such that we can transform the entire
        bitarray buffer at once.  Hence, we don't use a->nbits / 4 here, as
@@ -519,7 +521,6 @@ ba2hex(PyObject *module, PyObject *obj)
     be = IS_BE(a);
     for (i = 0; i < strsize; i += 2) {
         unsigned char c = a->ob_item[i / 2];
-
         str[i + le] = hexdigits[c >> 4];
         str[i + be] = hexdigits[0x0f & c];
     }
@@ -538,7 +539,7 @@ the bitarray (which has to be multiple of 4 in length).");
 
 /* Translate hexadecimal digits 'bytes' into the bitarray 'a' buffer.
    Each digit corresponds to 4 bits in the bitarray.
-   The number of digits may be odd. */
+   Note that the number of hexadecimal digits may be odd. */
 static int
 hex2ba_core(bitarrayobject *a, PyObject *bytes)
 {
@@ -614,7 +615,7 @@ hex2ba(PyObject *module, PyObject *args, PyObject *kwds)
     if ((bytes = anystr_to_bytes(obj)) == NULL)
         return NULL;
 
-    a = new_bitarray(4 * PyBytes_GET_SIZE(bytes), endian);
+    a = new_bitarray(4 * PyBytes_GET_SIZE(bytes), endian, -1);
     if (a == NULL)
         goto error;
 
@@ -803,7 +804,7 @@ base2ba(PyObject *module, PyObject *args, PyObject *kwds)
     if ((bytes = anystr_to_bytes(obj)) == NULL)
         return NULL;
 
-    a = new_bitarray(m * PyBytes_GET_SIZE(bytes), endian);
+    a = new_bitarray(m * PyBytes_GET_SIZE(bytes), endian, -1);
     if (a == NULL)
         goto error;
 
@@ -1030,9 +1031,8 @@ byte_length(Py_ssize_t i)
 static Py_ssize_t *
 sc_calc_rts(bitarrayobject *a)
 {
-    /* total number of segments - number of complete segments */
-    const Py_ssize_t n_seg = NSEG(a->nbits);
-    const Py_ssize_t c_seg = a->nbits / (8 * SEGSIZE);
+    const Py_ssize_t n_seg = NSEG(a->nbits);  /* total number of segments */
+    const Py_ssize_t c_seg = a->nbits / (8 * SEGSIZE); /* complete segments */
     char zeros[SEGSIZE];                      /* segment with only zeros */
     Py_ssize_t cnt = 0;                       /* current count */
     char *buff;                               /* buffer in current segment */
@@ -1161,8 +1161,8 @@ sc_write_raw(char *str, bitarrayobject *a, Py_ssize_t *rts, Py_ssize_t offset)
     return (int) k;
 }
 
-/* Write `k` indices (of `n` bytes each) into buffer `str`.
-   Note that `n` (which is also the block type) has been selected
+/* Write 'k' indices (of 'n' bytes each) into buffer 'str'.
+   Note that 'n' (which is also the block type) has been selected
    (in sc_encode_block()) such that:
 
        k = sc_count(a, rts, offset, n) < 256
@@ -1171,7 +1171,7 @@ static void
 sc_write_indices(char *str, bitarrayobject *a, Py_ssize_t *rts,
                  Py_ssize_t offset, int n, int k)
 {
-    const char *str_stop = str + n * k;  /* stop position in buffer `str` */
+    const char *str_stop = str + n * k;  /* stop position in buffer 'str' */
     const char *buff = a->ob_item + offset;
     Py_ssize_t m, i;
 
@@ -1213,8 +1213,8 @@ sc_write_indices(char *str, bitarrayobject *a, Py_ssize_t *rts,
     Py_UNREACHABLE();
 }
 
-/* Write one sparse block (from `offset`, and up to `k` one bits).
-   Return number of bytes written to buffer `str` (encoded block size). */
+/* Write one sparse block (from 'offset', and up to 'k' one bits) of type 'n'.
+   Return number of bytes written to buffer 'str' (encoded block size). */
 static Py_ssize_t
 sc_write_sparse(char *str, bitarrayobject *a, Py_ssize_t *rts,
                 Py_ssize_t offset, int n, int k)
@@ -1229,14 +1229,14 @@ sc_write_sparse(char *str, bitarrayobject *a, Py_ssize_t *rts,
         assert(k < 32);
         str[len++] = (char) (0xa0 + k);
     }
-    else {                 /* type 2, 3, 4 - `n` bytes for each positions */
+    else {                   /* type 2, 3, 4 - n bytes for each positions */
         str[len++] = (char) (0xc0 + n);
         str[len++] = (char) k;
     }
     if (k == 0)  /* no index bytes */
         return len;
 
-    /* write block data - `k` indices, `n` bytes per index */
+    /* write block data - k indices, n bytes per index */
     sc_write_indices(str + len, a, rts, offset, n, k);
     return len + n * k;
 }
@@ -1339,9 +1339,9 @@ sc_encode(PyObject *module, PyObject *obj)
     char *str;                  /* output buffer */
     Py_ssize_t len = 0;         /* bytes written into output buffer */
     bitarrayobject *a;
-    Py_ssize_t offset = 0;      /* block offset into bitarray `a` in bytes */
+    Py_ssize_t offset = 0;      /* block offset into bitarray a in bytes */
     Py_ssize_t *rts;            /* running totals for 256 bit segments */
-    Py_ssize_t t;               /* total population count of bitarray `a` */
+    Py_ssize_t t;               /* total population count of bitarray a */
 
     if (ensure_bitarray(obj) < 0)
         return NULL;
@@ -1516,12 +1516,11 @@ sc_decode(PyObject *module, PyObject *obj)
     if (sc_decode_header(iter, &endian, &nbits) < 0)
         goto error;
 
-    /* create bitarray of length 'nbits' and set all elements to 0 */
-    a = new_bitarray(nbits, Py_None);
+    /* create bitarray of length nbits */
+    a = new_bitarray(nbits, Py_None, 0);
     if (a == NULL)
         goto error;
     a->endian = endian;
-    memset(a->ob_item, 0x00, (size_t) Py_SIZE(a));
 
     /* consume blocks until stop byte is encountered */
     while ((increase = sc_decode_block(a, offset, iter))) {
@@ -1612,7 +1611,7 @@ vl_decode(PyObject *module, PyObject *args, PyObject *kwds)
         return PyErr_Format(PyExc_TypeError, "'%s' object is not iterable",
                             Py_TYPE(obj)->tp_name);
 
-    a = new_bitarray(32, endian);
+    a = new_bitarray(32, endian, -1);
     if (a == NULL)
         goto error;
 
